Passive Aggressive Holiday Digs - Elle
Description: From the latest studies on marriage to which celebrity is backing which charity, the latest and greatest in life and love news.
Keywords: lifestyle news, love news, lifestyle blog

# 8 Passive Aggressive Things That Were Said to Us Over the Holidays

December 29 6:30 PM
ELLE.com |

## Life & Love News

- SHARES
- TWEET

Ah, the holidays: A time for gift giving, family gathering, and passive aggressive rage flames. Here are some well-meaning but totally backhanded digs we heard over the holidays. Add your own in the comments. It feels good to vent.

From: Grandma
What she said: "Wouldn't it be nice to be in a relationship so you don't have to have roommates anymore?"
What we said: "I like my apartment; did Mom show you the new bar cart I found?"
What we wanted to say: "Literally the only thing harder than finding an affordable apartment in New York City is meeting a guy good enough to make you move out of it. If you know of a site that lists cute 1-bedrooms stocked with single guys, send it the hell over."

From Mom:
What she said: "It would be so nice to have some babies around here soon to open presents!"
What we said: HAHAHAHAHAHA.
What we wanted to say: HAHAHAHAHAHA.

From Aunt:
What she said: "Have you heard of this thing called Tinder?"
What we said: "Um, yes, kind of."
What we wanted to say: "If I hadn't heard of Tinder, I wouldn't have touched a male in over a year. So. Yes, yes I have."

From: Mother in Law:
What she said: "Did you REALLY cook all this yourself?"
What we said:" I sure did, hope you enjoy!"
What we wanted to say: "Just because I’m not giving up my career to cook three meals a day for your precious angel of a son doesn’t mean I can’t figure out which end of the turkey is which, lady."

From: Mom
What she said: "Maybe it’s time to see a therapist."
What we said: "Yeah, maybe that could help."
What we wanted to say: "I am already seeing a therapist to try and resolve my relationship issues before I’m doomed to die alone, THANKS!"

From: Mom:
What she said: "Did you go outside at all today?"
What we said: "Oh, haha, I guess I haven't!"
What we wanted to say: *crawls back under covers, fighting back shame waves*

From: Brother
What he said:"If she can wear that, then I don’t have to get dressed."
What we said: "Then don’t get dressed."
What we wanted to say: "Then don’t get dressed."

From a STRANGER at a Christmas party:
What she said: "I lived in New York and would have worked forever, like you, if my husband hadn’t moved us to Virginia. But really, you can’t work forever and wait to have kids. You should do Match.com. My sister did Match.com and she’s 42 and just got married and had a baby."
What we said: *Awkward polite laughter*
What we wanted to say: "Save some of that white wine for the rest of us…"

- SHARES
- TWEET

### Post a comment

### ELLE Everywhere

### Be an Insider

From our editors to your inbox. Sign up for our newsletter today.

Your Email Address

### Must Reads

- 1 33 Perfect Holiday Nail Polishes
- 2 43 Women Helping Us Change The World
- 3 How Leaning In Killed My Confidence
- 4 Scalpels and Tiaras: Inside the Beauty Pageant Factory
- 5 12 Products That Fight Winter Beauty Woes
- 6 27 Ways To Dress Like Beyonce For Under $100
- 7 15 Ways To Feel Cozy & Chic This Winter
- 8 In Defense Of The Beauty Splurge
- 9 The Living Christmas Ornament DIY

Follow ELLE on Pinterest

Powered By

See More Top Pins